==> mx-findshares_19.1.tar.xz: mx-findshares-19.1/translations/mx-findshares_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>mxfindshares</name>
    <message>
        <location filename="../mxfindshares.ui" line="14"/>
        <location filename="../mxfindshares.cpp" line="176"/>
        <source>MX Find Shares</source>
        <translation>MX Znajdź zasoby współdzielone</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="31"/>
        <source>Options:</source>
        <translation>Opcje:</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="37"/>
        <source>Show all shares</source>
        <translation>Pokaż wszystkie zasoby współdzielone </translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="44"/>
        <source>Show only Windows/Samba shares</source>
        <translation>Pokaż tylko współdzielone zasoby Windows/Samba</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="51"/>
        <source>Show only NFS shares</source>
        <translation>Pokaż tylko współdzielone NFS</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="61"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This program lists all the shares available on the network. When you press &amp;quot;Start&amp;quot; the program will display a list with machines and shares ordered by network groups, both local and remote.&lt;/p&gt;&lt;p&gt;Please choose one of the available options and press the &amp;quot;Start&amp;quot; button.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ten program wyświetla listę wszystkich zasobów współdzielonych w sieci. Gdy wciśniesz &amp;quot;Start&amp;quot; program pokaże listę maszyn i udziałów posortowaną według grup sieciowych (zarówno lokalnych jak i zdalnych).&lt;/p&gt; 
&lt;p&gt;Proszę wybierz jedną z dostępnych opcji i kliknij  &amp;quot;Start&amp;quot;.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="111"/>
        <source>Save results</source>
        <translation>Zapisz wyniki</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="148"/>
        <source>Display help </source>
        <translation>Wyświetl pomoc</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="151"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="159"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="194"/>
        <source>Start scanning for shares</source>
        <translation>Skanuj w poszukiwaniu zasobów</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="197"/>
        <location filename="../mxfindshares.cpp" line="158"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="224"/>
        <source>Quit application</source>
        <translation>Zamknij apliikację</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="227"/>
        <location filename="../mxfindshares.cpp" line="183"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="235"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="251"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="254"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="262"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="105"/>
        <source>Finished searching for shares.</source>
        <translation>Wyszukiwanie zasobów zakończone.</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="107"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="108"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Proces zakończony z błędami.</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="112"/>
        <source>&lt; Back</source>
        <translation>&lt; Wstecz</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="175"/>
        <source>About MX Find Shares</source>
        <translation>O MX Znajdź zasoby współdzielone</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="176"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="178"/>
        <source>Simple package for finding network shares for MX Linux</source>
        <translation>Prosty program do wyszukiwania zasobów współdzielonych dla dystrybucji MX Linux</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="179"/>
        <source>This program is composed of two packages:</source>
        <translation>Program składa się z dwóch pakietów:</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="181"/>
        <source>Copyright (c) MX Linux
</source>
        <translation>Copyright (c) MX Linux
</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="182"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="202"/>
        <source>Save File</source>
        <translation>Zapisz plik</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="203"/>
        <source>network_shares.txt</source>
        <translation>network_shares.txt</translation>
    </message>
</context>
</TS>

==> mx-findshares_19.7.tar.xz: mx-findshares-19.7/translations/mx-findshares_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>mxfindshares</name>
    <message>
        <location filename="../mxfindshares.ui" line="14"/>
        <location filename="../mxfindshares.cpp" line="177"/>
        <source>MX Find Shares</source>
        <translation>MX Znajdź udziały</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="31"/>
        <source>Options:</source>
        <translation>Opcje:</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="37"/>
        <source>Show all shares</source>
        <translation>Pokaż wszystkie udziały sieciowe</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="44"/>
        <source>Show only Windows/Samba shares</source>
        <translation>Pokaż tylko współdzielone zasoby Windows/Samba</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="51"/>
        <source>Show only NFS shares</source>
        <translation>Pokaż tylko współdzielone zasoby NFS</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="61"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This program lists all the shares available on the network. When you press &amp;quot;Start&amp;quot; the program will display a list with machines and shares ordered by network groups, both local and remote.&lt;/p&gt;&lt;p&gt;Please choose one of the available options and press the &amp;quot;Start&amp;quot; button.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ten program wyświetla listę wszystkich zasobów współdzielonych w sieci (udziałów sieciowych). Gdy wciśniesz &amp;quot;Start&amp;quot; program pokaże listę maszyn i udziałów posortowaną według grup sieciowych (zarówno lokalnych jak i zdalnych).&lt;/p&gt; 
&lt;p&gt;Proszę wybierz jedną z dostępnych opcji i kliknij  &amp;quot;Start&amp;quot;.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="111"/>
        <source>Save results</source>
        <translation>Zapisz wyniki</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="148"/>
        <source>Display help </source>
        <translation>Wyświetl pomoc</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="151"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="159"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="194"/>
        <source>Start scanning for shares</source>
        <translation>Skanuj w poszukiwaniu zasobów</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="197"/>
        <location filename="../mxfindshares.cpp" line="159"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="224"/>
        <source>Quit application</source>
        <translation>Zakończ aplikację</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="227"/>
        <location filename="../mxfindshares.cpp" line="184"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="235"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="251"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="254"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mxfindshares.ui" line="262"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="106"/>
        <source>Finished searching for shares.</source>
        <translation>Wyszukiwanie zasobów zakończone.</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="108"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="109"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Proces zakończony. Wystąpiły błędy.</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="113"/>
        <source>&lt; Back</source>
        <translation>&lt; Wstecz</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="176"/>
        <source>About MX Find Shares</source>
        <translation>O programie MX Znajdź udziały</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="177"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="179"/>
        <source>Simple package for finding network shares for MX Linux</source>
        <translation>Prosty program do wyszukiwania udziałów sieciowych (zasobów współdzielonych) dla dystrybucji MX Linux</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="180"/>
        <source>This program is composed of two packages:</source>
        <translation>Program składa się z dwóch pakietów:</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="182"/>
        <source>Copyright (c) MX Linux
</source>
        <translation>Prawa autorskie © MX Linux
</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="183"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="203"/>
        <source>Save File</source>
        <translation>Zapisz plik</translation>
    </message>
    <message>
        <location filename="../mxfindshares.cpp" line="204"/>
        <source>network_shares.txt</source>
        <translation>network_shares.txt</translation>
    </message>
</context>
</TS>
